<?php
/**
* 2007-2021 PrestaShop
*
* NOTICE OF LICENSE
*
* This source file is subject to the Academic Free License (AFL 3.0)
* that is bundled with this package in the file LICENSE.txt.
* It is also available through the world-wide-web at this URL:
* http://opensource.org/licenses/afl-3.0.php
* If you did not receive a copy of the license and are unable to
* obtain it through the world-wide-web, please send an email
* to license@prestashop.com so we can send you a copy immediately.
*
* DISCLAIMER
*
* Do not edit or add to this file if you wish to upgrade PrestaShop to newer
* versions in the future. If you wish to customize PrestaShop for your
* needs please refer to http://www.prestashop.com for more information.
*
*  @author    PrestaShop SA <contact@prestashop.com>
*  @copyright 2007-2021 PrestaShop SA
*  @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
*  International Registered Trademark & Property of PrestaShop SA
*/

if (!defined('_PS_VERSION_')) {
    exit;
}

/*
$autoloadPath = __DIR__ . '/vendor/autoload.php';
if (file_exists($autoloadPath)) {
    require_once $autoloadPath;
}
*/

use PrestaShop\PrestaShop\Core\Module\WidgetInterface;

class DataAppsFTSS extends Module implements WidgetInterface  
{
    protected $config_form = false;

    public function __construct()
    {
        $this->name = 'DataAppsFTSS';
        $this->tab = 'search_filter';
        $this->version = '1.0.0';
        $this->author = 'DataAPPs';
        $this->need_instance = 0;

        /**
         * Set $this->bootstrap to true if your module is compliant with bootstrap (PrestaShop 1.6)
         */
        $this->bootstrap = true;

        parent::__construct();

        $this->displayName = $this->l('DataAPPs FTSS');
        $this->description = $this->l('Fulltext search suggestion (autocomplete) for web and eshop.');

        $this->ps_versions_compliancy = array('min' => '1.6', 'max' => _PS_VERSION_);
        
        /**
         * Require standard PS Searchbar module
         */
        $this->templateFile = 'module:ps_searchbar/ps_searchbar.tpl';
    }

    /**
     * Don't forget to create update methods if needed:
     * http://doc.prestashop.com/display/PS16/Enabling+the+Auto-Update
     */
    public function install()
    {
        Configuration::updateValue('DATAAPPSFTSS_LIVE_MODE', false);
        Configuration::updateValue('DATAAPPSFTSS_OVERWRITE_CSS', false);
        
		//return parent::install() && $this->registerHook('header');
		
		return parent::install() 
			&& $this->registerHook('top')
            && $this->registerHook('displaySearch')
            && $this->registerHook('header') 
		;
    }

    public function uninstall()
    {
        Configuration::deleteByName('DATAAPPSFTSS_ID');
        Configuration::deleteByName('DATAAPPSFTSS_LIVE_MODE');
        Configuration::deleteByName('DATAAPPSFTSS_OVERWRITE_CSS');
        
        return parent::uninstall();
    }

    /**
     * Load the configuration form
     */
    public function getContent()
    {
        /**
         * If values have been submitted in the form, process.
         */
        if (((bool)Tools::isSubmit('submitDataAppsFTSSModule')) == true) {
            $this->postProcess();
        }

        $this->context->smarty->assign('module_dir', $this->_path);

        $output = $this->context->smarty->fetch($this->local_path.'views/templates/admin/configure.tpl');

        return $output.$this->renderForm();
    }

    /**
     * Create the form that will be displayed in the configuration of your module.
     */
    protected function renderForm()
    {
        $helper = new HelperForm();

        $helper->show_toolbar = false;
        $helper->table = $this->table;
        $helper->module = $this;
        $helper->default_form_language = $this->context->language->id;
        $helper->allow_employee_form_lang = Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG', 0);

        $helper->identifier = $this->identifier;
        $helper->submit_action = 'submitDataAppsFTSSModule';
        $helper->currentIndex = $this->context->link->getAdminLink('AdminModules', false)
            .'&configure='.$this->name.'&tab_module='.$this->tab.'&module_name='.$this->name;
        $helper->token = Tools::getAdminTokenLite('AdminModules');

        $helper->tpl_vars = array(
            'fields_value' => $this->getConfigFormValues(), /* Add values for your inputs */
            'languages' => $this->context->controller->getLanguages(),
            'id_language' => $this->context->language->id,
        );

        return $helper->generateForm(array($this->getConfigForm()));
    }

    /**
     * Create the structure of your form.
     */
    protected function getConfigForm()
    {
        return array(
            'form' => array(
                'legend' => array(
                'title' => $this->l('Settings'),
                'icon' => 'icon-cogs',
                ),
                'input' => array(
                    array(
                        'col' => 4,
                        'type' => 'text',
                        //'prefix' => '<i class="icon icon-envelope"></i>',
                        'desc' => $this->l('Enter fulltext search suggestion ID (get Your ID on www.data-apps.cz)'),
                        'name' => 'DATAAPPSFTSS_ID',
                        'label' => $this->l('FTSS ID'),
                    ),
					array(
                        'type' => 'switch',
                        'label' => $this->l('Overwrite CSS'),
                        'name' => 'DATAAPPSFTSS_OVERWRITE_CSS',
                        'is_bool' => true,
                        'desc' => $this->l('Overwrite CSS of search widget (change width to 75% and wrap to new line in classic theme)'),
                        'values' => array(
                            array(
                                'id' => 'active_on',
                                'value' => true,
                                'label' => $this->l('Enabled')
                            ),
                            array(
                                'id' => 'active_off',
                                'value' => false,
                                'label' => $this->l('Disabled')
                            )
                        ),
                    ),
                ),
                'submit' => array(
                    'title' => $this->l('Save'),
                ),
            ),
        );
    }

    /**
     * Set values for the inputs.
     */
    protected function getConfigFormValues()
    {
        return array(
            'DATAAPPSFTSS_ID' => Configuration::get('DATAAPPSFTSS_ID', null),
        	'DATAAPPSFTSS_LIVE_MODE' => Configuration::get('DATAAPPSFTSS_LIVE_MODE', false),
            'DATAAPPSFTSS_OVERWRITE_CSS' => Configuration::get('DATAAPPSFTSS_OVERWRITE_CSS', false),
        );
    }

    /**
     * Save form data.
     */
    protected function postProcess()
    {
        $form_values = $this->getConfigFormValues();

        foreach (array_keys($form_values) as $key) {
            Configuration::updateValue($key, Tools::getValue($key));
        }
    }

    /**
     * Add the CSS & JavaScript files you want to be added on the FO.
     */
    public function hookHeader()
    {
    	/**
         * Require standard PS Searchbar module
         */
		$this->context->controller->registerStylesheet(
			'modules-searchbar', 
			'modules/ps_searchbar/ps_searchbar.css'
		);
		
		/**
		 * DataAPPs FTSS extended CSS
		 */
    	$cssOn = Configuration::get('DATAAPPSFTSS_OVERWRITE_CSS', false);
		if ($cssOn == true) {
			$this->context->controller->registerStylesheet(
	            'dataappsftss-css',
	            'modules/DataAppsFTSS/views/css/front.ext.css',
	            [ 'media' => 'all', 'priority' => 997 ]
	        );
	    } else {
			$this->context->controller->registerStylesheet(
	            'dataappsftss-css',
	            'modules/DataAppsFTSS/views/css/front.std.css',
	            [ 'media' => 'all', 'priority' => 997 ]
	        );
		}
        
		/**
		 * DataAPPs FTSS std JS lib
		 */
	    $this->context->controller->registerJavascript(
            'dataappsftss-jslib',
            'https://cdn.dataapps.cz/apps/ftss/ftss.stable.js',
            [ 'position' => 'head', 'priority' => 998, 'attributes' => 'async', 'server' => 'remote' ]
        );
        
		/**
		 * DataAPPs FTSS conf JS
		 */
        $ftssId = Configuration::get('DATAAPPSFTSS_ID', null);
        if (!empty($ftssId) && preg_match("/^[a-z0-9]{10,96}$/i", $ftssId)) {        
	        $this->context->controller->registerJavascript(
	            'dataappsftss-jscfg',
	            'https://cdn.dataapps.cz/apps/ftss/'. trim($ftssId) .'/ftss.'. trim($ftssId) .'.js',
	            [ 'position' => 'head', 'priority' => 999, 'attributes' => 'async', 'server' => 'remote' ]
	        );
        }
    }
    
	public function getWidgetVariables($hookName, array $configuration = [])
	{
        $widgetVariables = [
            'search_controller_url' => $this->context->link->getPageLink('search', null, null, null, false, null, true),
        ];

        /** @var array $templateVars */
        $templateVars = $this->context->smarty->getTemplateVars();
        if (is_array($templateVars) && !array_key_exists('search_string', $templateVars)) {
            $widgetVariables['search_string'] = '';
        }

        return $widgetVariables;
    }

    public function renderWidget($hookName, array $configuration = [])
	{
        $this->smarty->assign($this->getWidgetVariables($hookName, $configuration));

        return $this->fetch($this->templateFile);
    }
    
} //end class
